<?php
/**
 * Requried functions for theme backend.
 *
 * @package billiard
 * @subpackage Template
 */

// cs framework missing
if (! function_exists('cs_get_option')) {
   function cs_get_option(){
    return '';
   }
   function cs_get_customize_option(){
    return '';
   }
}

// woocommerce missing
if (! function_exists('is_cart')) {
   function is_cart(){
    return '';
   }
}
if (! function_exists('is_checkout')) {
   function is_checkout(){
    return '';
   }
}

function billiard_get_post_preview_header( $blog_style, $meta, $post_id ){
	$meta['post_preview_style'] = ( ! empty( $meta['post_preview_style'] ) ) ? $meta['post_preview_style'] : 'default';
	switch ( $blog_style ) {
		case 'classic':
			billiard_get_post_header($meta, $post_id);
			break;
		case 'isotope':
			billiard_isotope_header($meta, $post_id);
			break;
		}
}

function billiard_isotope_header($meta, $post_id) {
	$style = isset( $meta['post_preview_style'] ) ? $meta['post_preview_style'] : 'none';
	switch ( $style ) {
		case 'none':
			// Silence is golden.
			break;
		case 'default':
			?> <div class="blog-item-img"> <?php
				if ( has_post_thumbnail( $post_id ) ) {
					echo get_the_post_thumbnail( $post_id, 'full' );
				}
			?> </div> <?php
			break;
		case 'image':
			if( ! empty( $meta['post_image'] ) ) { 
				$img = wp_get_attachment_image_src( $meta['post_image'], 'full' ); ?>
				<div class="bg bg-bg-chrome act" style="background-image:url(<?php echo esc_url( $img['0'] ); ?>)"></div>
			<?php }
			break;
		case 'slider':
			if( ! empty( $meta['post_slider'] ) ) { 
				$ids = explode( ',', $meta['post_slider'] ); ?>
				<div class="swiper-container main-slider" data-autoplay="4000" data-touch="1" data-mouse="0" data-slides-per-view="1" data-loop="0" data-speed="1200" data-mode="horizontal">                 
					<div class="swiper-wrapper">
						<?php foreach ( $ids as $id ) {
							$img = wp_get_attachment_image_src( $id, 'full' ); ?>
							<div class="swiper-slide">
									<img src="<?php echo esc_url( $img[0] ); ?>">
							</div>
						<?php } ?>
					</div>
					<div class="slide-prev"></div>
					<div class="slide-next"></div>
					<div class="pagination vertical-mode"></div>
				</div>
			<?php }
			break;
		case 'video':
			if( ! empty( $meta['post_video'] ) ) {
				$embed = wp_oembed_get( $meta['post_video'] ); 
				$class = ( strpos( $meta['post_video'], 'soundcloud' ) ) ? 'sound' : 'video'; ?>
				<div class="video-wrap">
						<div class="<?php echo esc_attr( $class ); ?>">
								<?php print $embed; ?>
						</div>
				</div>
			<?php }
			break;
	}
}

function billiard_get_post_header($meta, $post_id) {
	$key = ( isset( $meta['post_preview_style'] ) ) ? $meta['post_preview_style'] : 'default';
	switch ( $key ) {
		case 'none':
			// Silence is golden.
			break;
		case 'default':
			if ( has_post_thumbnail( $post_id ) ) {
				echo get_the_post_thumbnail( $post_id, 'full' );
			}
			break;
		case 'image': 
			if( ! empty( $meta['post_image'] ) ) { 
				$img = wp_get_attachment_image_src( $meta['post_image'], 'full' ); ?>
				<div class="post-image">
					<img src="<?php echo esc_url( $img['0'] );?>">
				</div>
			<?php }
			break;
		case 'slider':
			if( ! empty( $meta['post_slider'] ) ) { 
				$ids = explode( ',', $meta['post_slider'] ); ?>
				<div class="swiper-container main-slider" data-autoplay="4000" data-touch="1" data-mouse="0" data-slides-per-view="1" data-loop="0" data-speed="1200" data-mode="horizontal"> 				  
					<div class="swiper-wrapper">
						<?php foreach ( $ids as $id ) {
							$img = wp_get_attachment_image_src( $id, 'full' ); ?>
							<div class="swiper-slide">
								<img src="<?php echo esc_url( $img[0] ); ?>">
							</div>
						<?php } ?>
					</div>
					<div class="slide-prev"></div>
					<div class="slide-next"></div>
					<div class="pagination vertical-mode"></div>
				</div>
			<?php }
			break;
		case 'video':
			if( ! empty( $meta['post_video'] ) ) {
				$embed = wp_oembed_get( $meta['post_video'] ); 
				$class = ( strpos( $meta['post_video'], 'soundcloud' ) ) ? 'sound' : 'video'; ?>
				<div class="video-wrap">
					<div class="<?php echo esc_attr( $class ); ?>">
						<?php print $embed; ?>
					</div>
				</div>
			<?php } 
			break;
	}
}

function billiard_get_post_views( $postID ) {
	$count_key = 'post_views_count';
	$count = get_post_meta( $postID, $count_key, true );
	if( $count == '' ){
		delete_post_meta( $postID, $count_key );
		add_post_meta( $postID, $count_key, '0' );
		return "0";
	}
	return $count;
}

function billiard_set_post_views( $postID ) {
	$count_key = 'post_views_count';
	$count = get_post_meta( $postID, $count_key, true );
	if( $count == '' ) {
		$count = 0;
		delete_post_meta( $postID, $count_key );
		add_post_meta( $postID, $count_key, '0' );
	} else {
		$count++;
		update_post_meta( $postID, $count_key, $count );
	}
}

/*
 * Get site logo.
 */
function billiard_logo() {
	$billiard = billiard_site_options();
	if(  isset( $billiard['logo_type'] ) ) {
		if( $billiard['logo_type'] == 'text' ) {
			echo esc_html( $billiard['text_logo'] );
		} else {
			$retina = ( ! empty( $billiard['image_retina_logo'] ) ) ? 'data-retina="' . esc_url( $billiard['image_retina_logo'] ) . '"' : '';
			echo '<img ' . $retina . ' src="' . esc_url( $billiard['image_logo'] ) . '" alt=""/>';
		}
	} else {
		esc_html_e( 'billiard', 'billiard' );
	}
}

/*
 * Get site footer.
 */
function billiard_footer() {
	$billiard = billiard_site_options();
	if( has_nav_menu( 'footer-menu' ) || ! empty( $billiard['footer_copyright'] ) || !class_exists('CSFramework') ) {
		$footer_style = ( ! empty( $billiard['footer_style'] ) ) ? $billiard['footer_style'] : '';
		$output = '<footer class="main-footer ' . esc_attr( $footer_style ) . '"><div class="container no-padding"><div class="footer"><div class="vertical-align">';
		if(!class_exists('CSFramework')) {
			if( has_nav_menu( 'footer-menu' ) ) {
				$output .= '<div class="footer-link">';
				$output .= wp_nav_menu( 
					array( 
						'echo'           => false, 
						'depth'          => 1, 
						'container'      => '', 
						'theme_location' => 'footer-menu',
					)
				);
				$output .= '</div>';
			} else {
				$output .='<div class="no-menu"><div class="table-cell">' . esc_html__( 'Please register Footer menu', 'billiard' ) . ' <a href="' . esc_url( admin_url( 'nav-menus.php' ) ) . '" target="_blank">' . esc_html__( 'Appearance &gt; Menus', 'billiard' ) . '</a></div></div>';
			}
		}
		if( ! empty( $billiard['footer_copyright'] ) ) {

			$output .= '<div class="footer-folow">';
			$output .= '<p>' . esc_html( $billiard['footer_copyright'] ) . '</p>';
			$output .= '</div>';

		}
		$output .= '</div></div></div>';
		$output .= '</footer>';
		echo wp_kses_post( $output ); 
	}
}

/**
 *
 * Helper Functions
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if ( ! function_exists( 'billiard_site_options' ) ) {
	function billiard_site_options() {
		if( function_exists( 'cs_framework_init' ) ) { 
			$options = apply_filters( 'cs_get_option', get_option( CS_OPTION ) );
			return $options;
		} else {
			return false;
		}
	}
}

function billiard_wp_link_pages() {
	get_post_format();
}

/**
 *
 * Create custom html structure for comments
 *
 */
function billiard_comment( $comment, $args, $depth ) {

	$GLOBALS['comment'] = $comment;

	$reply_class = ( $comment->comment_parent ) ? 'indented' : '';
	switch ( $comment->comment_type ):
		case 'pingback':
		case 'trackback': ?>
			<div class="pingback">
				<?php esc_html_e( 'Pingback:', 'billiard' ); ?> <?php comment_author_link(); ?>
				<?php edit_comment_link( esc_html__( '(Edit)', 'billiard' ), '<span class="edit-link">', '</span>' ); ?>
			</div>
			<?php
			break;
		default:
			// generate comments
			?>
			<li <?php comment_class('ct-part'); ?> id="li-comment-<?php comment_ID(); ?>">
				<div class="comm-block" id="comment-<?php comment_ID(); ?>">
					<div class="comm-img">
							<?php print get_avatar( $comment, 80 ); ?>
					</div>
					<div class="comm-meta">
						<h5><?php the_author_meta('nickname'); ?></h5>
						<?php
							comment_reply_link(
								array_merge( $args,
									array(
										'reply_text' => esc_html__( 'Reply', 'billiard' ),
										'after' => '',
										'depth' => $depth,
										'max_depth' => $args['max_depth']
									)
								)
							);
						?>
						<div class="comm-txt">
						<?php comment_text(); ?>
						
					</div>
						<div class="date-post">
							<h6><?php comment_date( get_option('date_format') );?>
							<?php echo 'at ' . human_time_diff(get_the_time('U'), current_time('timestamp')) . ' ago'; ?></h6>
						</div>
					</div>
					
				</div>
		<?php
		break;
	endswitch;
}

/**
 *
 * Get categories for shortcode.
 * @since 1.0.0
 * @version 1.0.0
 *
 */
function billiard_categories( $post_type ) {

	$cats = array(
		'post'      => 'category',
		'portfolio' => 'portfolio-category'
	);

	$categories = get_terms( $cats[$post_type] );

	$list = array();
	if( ! empty( $categories ) ) {
		foreach ( $categories as $category ) {
			$list[$category->name] = $category->slug;
		}
	}
	return $list;
}

/*
 * Change exerpt end. 
 */
function billiard_excerpt_more( $more ) {
	return '...';
}
add_filter('excerpt_more', 'billiard_excerpt_more');


// Remove role attribute from search form.
function billiard_valid_search_form ($form) {
	return str_replace('role="search" ', '', $form);
}
add_filter('get_search_form', 'billiard_valid_search_form');

// Add custom class for body tag
function billiard_custom_body_class( $classes ) {
	$billiard = billiard_site_options();
	if( ! isset( $billiard['preloader'] ) || $billiard['preloader'] ) {
	    $classes[] = 'animsition';
	} 

	if( ! class_exists('Billiard_Plugins') ) {
        $classes[] .= ' no-billiard-plugins';
    }

    return $classes;
}
add_filter( 'body_class', 'billiard_custom_body_class' );
/* *
 * Post input form
 * @since 1.0.0
 * @version 1.0.0
 *
 **/
if ( ! function_exists( 'billiard_reorder_comment_fields' ) ) {
    function billiard_reorder_comment_fields( $fields ){

        $new_fields = array();

        $myorder = array('author','email');

        foreach( $myorder as $key ){
            $new_fields[ $key ] = $fields[ $key ];
            unset( $fields[ $key ] );
        }

        if( $fields )
            foreach( $fields as $key => $val )
                $new_fields[ $key ] = $val;

        return $new_fields;
    }
    add_filter('comment_form_fields', 'billiard_reorder_comment_fields' );
}

if ( ! function_exists( 'billiard_mini_cart' ) ) {
	function billiard_mini_cart() {
		if ( ! WC()->cart->is_empty() ) : ?>

		<ul class="woocommerce-mini-cart cart_list product_list_widget">
			<?php
				do_action( 'woocommerce_before_mini_cart_contents' );

				foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
					$_product     = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
					$product_id   = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

					if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_widget_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
						$product_name      = apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key );
						$thumbnail         = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );
						$product_price     = apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
						$product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
						?>
						<li class="woocommerce-mini-cart-item <?php echo esc_attr( apply_filters( 'woocommerce_mini_cart_item_class', 'mini_cart_item', $cart_item, $cart_item_key ) ); ?>">
							<div class="remove">
								<?php
								echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf(
									'<a href="%s" class="remove" aria-label="%s" data-product_id="%s" data-product_sku="%s">&times;</a>',
									esc_url( WC()->cart->get_remove_url( $cart_item_key ) ),
									__( 'Remove this item', 'billiard' ),
									esc_attr( $product_id ),
									esc_attr( $_product->get_sku() )
								), $cart_item_key );
								?>
							</div>
							<?php if ( ! $_product->is_visible() ) : ?>
								<?php echo str_replace( array( 'http:', 'https:' ), '', $thumbnail ) . $product_name . '&nbsp;'; ?>
							<?php else : ?>
								<a href="<?php echo esc_url( $product_permalink ); ?>">
									<?php echo str_replace( array( 'http:', 'https:' ), '', $thumbnail ); ?>
								</a>
								<h4><?php echo wp_kses_post($product_name); ?></h4>
							<?php endif; ?>

							<?php echo WC()->cart->get_item_data( $cart_item ); ?>

							<?php echo apply_filters( 'woocommerce_widget_cart_item_quantity', '<span class="quantity">' . sprintf( '%s &times; %s', $cart_item['quantity'], $product_price ) . '</span>', $cart_item, $cart_item_key ); ?>
						</li>
						<?php
					}
				}

				do_action( 'woocommerce_mini_cart_contents' );
			?>
		</ul>

		<p class="woocommerce-mini-cart__total total"><strong><?php _e( 'Subtotal', 'billiard' ); ?>:</strong> <?php echo WC()->cart->get_cart_subtotal(); ?></p>

		<?php do_action( 'woocommerce_widget_shopping_cart_before_buttons' ); ?>

		<p class="woocommerce-mini-cart__buttons buttons"><?php do_action( 'woocommerce_widget_shopping_cart_buttons' ); ?></p>

		<?php else : ?>

			<p class="woocommerce-mini-cart__empty-message"><?php _e( 'No products in the cart.', 'billiard' ); ?></p>

		<?php endif;
	}
}

// Custom row styles for onepage site type+-.
if ( ! function_exists('billiard_dynamic_css' ) ) {
    function billiard_dynamic_css() {
        require_once get_template_directory() . '/assets/css/custom.css.php';
        wp_die();
    }
}
add_action( 'wp_ajax_nopriv_billiard_dynamic_css', 'billiard_dynamic_css' );
add_action( 'wp_ajax_billiard_dynamic_css', 'billiard_dynamic_css' );



add_filter( 'woocommerce_add_to_cart_fragments', 'billiard_fuller_header_add_to_cart_fragment' );
function billiard_fuller_header_add_to_cart_fragment( $fragments ) {
    ob_start(); ?>

    <span class="icon-cart-count"><?php echo WC()->cart->get_cart_contents_count(); ?></span>

    <?php $fragments['span.icon-cart-count'] = ob_get_clean();
    return $fragments;
}

add_filter( 'woocommerce_add_to_cart_fragments', function($fragments) {

   ob_start(); ?>

    <div class="mini-cart-wrap js-inner-elem">
        <?php billiard_mini_cart(); ?>
    </div>

   <?php $fragments['div.mini-cart-wrap'] = ob_get_clean();
    return $fragments;

} );