<?php
/**
 * The template includes necessary functions for theme.
 *
 * @package billiard
 * @since 1.0.0
 */

if ( ! isset( $content_width ) ) {
    $content_width = 960; /* pixels */
}

defined( 'BILLIARD_URI' )    or define( 'BILLIARD_URI',    get_template_directory_uri() );
defined( 'BILLIARD_T_PATH' ) or define( 'BILLIARD_T_PATH', get_template_directory() );
defined( 'BILLIARD_F_PATH' ) or define( 'BILLIARD_F_PATH', BILLIARD_T_PATH . '/include' ); 

// Framework integration
// --------------------------------------------------------------------
require_once BILLIARD_T_PATH . '/custom/actions-config.php';
require_once BILLIARD_T_PATH . '/custom/helper-functions.php';
require_once BILLIARD_T_PATH . '/custom/class-tgm-plugin-activation.php';

require BILLIARD_T_PATH . '/vendor/autoload.php';

if ( class_exists( 'WooCommerce' ) ) {
    require_once BILLIARD_T_PATH . '/woocommerce-support.php';
}



/**
 * Initialize the plugin tracker
 *
 * @return void
 */
function appsero_init_tracker_billiard() {

	if ( ! class_exists( 'Appsero\Client' ) ) {
		require_once BILLIARD_T_PATH . '/vendor/appsero/client/src/Client.php';
	}


	$client = new Appsero\Client( '0046b633-0073-4648-b723-03c21e46e737', 'Billiard', __FILE__ );

	// Active insights
	$client->insights()->init();

	// Active automatic updater
	$client->updater();

}

appsero_init_tracker_billiard();



function billiard_after_setup() {

    load_theme_textdomain( 'billiard', get_template_directory() . '/languages' );

    register_nav_menus( 
        array( 
            'top-menu'     => esc_html__( 'Primary menu', 'billiard' ),
            'footer-menu'  => esc_html__( 'Footer menu',  'billiard' )
        ) 
    );
    
    add_theme_support( 'post-formats', array('video', 'gallery', 'audio', 'quote', 'image', 'link'));
    add_theme_support( 'custom-header' );
    add_theme_support( 'custom-background' );
    add_theme_support( 'automatic-feed-links' );
    add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption' ) );
    add_theme_support( 'post-thumbnails' );
    add_theme_support( 'title-tag' );
    // Add woocommerce support
    add_theme_support( 'woocommerce' );
	remove_theme_support( 'widgets-block-editor' );
}
add_action( 'after_setup_theme', 'billiard_after_setup' );

/**
 * Custom billiard menu.
 */
function billiard_custom_menu() {
    if ( has_nav_menu( 'top-menu' ) ) {
        wp_nav_menu( 
            array( 
                'container'       => '', 
                'items_wrap'      => '<ul class="table-cell">%3$s</ul>',
                'theme_location'  => 'top-menu',
                'depth'           => 3
            )
        );
    } else {
        echo '<div class="no-menu"><div class="table-cell">' . esc_html__( 'Please register Top Navigation from', 'billiard' ) . ' <a href="' . esc_url( admin_url( 'nav-menus.php' ) ) . '" target="_blank">' . esc_html__( 'Appearance &gt; Menus', 'billiard' ) . '</a></div></div>';
    }
}

// Change a currency symbol in WooCommerce
add_filter('woocommerce_currency_symbol', 'billiard_change_existing_currency_symbol', 10, 2);

function billiard_change_existing_currency_symbol( $currency_symbol, $currency ) {
     switch( $currency ) {
          case 'AUD': $currency_symbol = 'AUD$'; break;
     }
     return $currency_symbol;
}

// 
if ( class_exists( 'WooCommerce' ) ) {
    require_once BILLIARD_T_PATH . '/woocommerce-support.php';
}

add_theme_support( 'wc-product-gallery-lightbox' );
add_theme_support( 'wc-product-gallery-slider' );




function sample_admin_notice__success() {
   
	if (is_plugin_active( 'booked/booked.php' ) ) { ?>
    <div data-dismissible="disable-done-notice-forever" class="updated notice notice-success is-dismissible">
        <p><?php _e( '<b>Booked plugin has been deprecated since version 2.4.3</b>, instead of using Booked plugin you can use <a  href="https://import.foxthemes.me/plugins/premium-plugins/scheduled.zip" target="_blank">Scheduled Plugin.</a>. Please make sure to take a backup before replacing plugin.'); ?></p> 
    </div>
    <?php 
	}
}
add_action( 'admin_notices', 'sample_admin_notice__success' );
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328501&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        