<?php 
/* All functions for WooCommerce */

/* add support woocommerce to theme */
if ( ! function_exists('billiard_woocommerce_support' ) ) {
	function billiard_woocommerce_support( )
	{
		add_theme_support( 'woocommerce' );
	}
}
add_action( 'after_setup_theme', 'billiard_woocommerce_support' );

if ( ! function_exists('billiard_woocommerce_scripts')) {
	function billiard_woocommerce_scripts()
	{	

		// billiard options
		$billiard = wp_get_theme();

		wp_enqueue_style( 'billiard_woocommerce_style', get_template_directory_uri() . '/woocommerce-support.css', array(), apply_filters( 'billiard_version_filter', $billiard->get( 'Version' ) ) );

		if ( is_product() ) {
			wp_enqueue_script( 'billiard_woocommerce_js', get_template_directory_uri() . '/woocommerce-support.js', array( 'jquery' ), apply_filters( 'billiard_version_filter', $billiard->get( 'Version' )), true );
		}
	}
}
add_action( 'wp_enqueue_scripts', 'billiard_woocommerce_scripts');

/* eccommerce_theme_options filters */
if ( ! function_exists('billiard_woocommerce_theme_options')) {
	function billiard_woocommerce_theme_options($options)
	{

		$options = array();

		$options[] = array(
			'name'   => 'ecommerce_options',
			'title'  => 'Ecommerce',
			'icon'   => 'fa fa-shopping-cart',
			// begin: fields
			'fields' => array(
			  array(
			    'id'      => 'shop_heading_image',
			    'type'    => 'image',
			    'title'   => esc_html__('Shop heading Image', 'billiard'),
			  ),  
			  array(
			    'id'      => 'shop_heading_title',
			    'type'    => 'text',
			    'title'   => esc_html__('Shop heading title', 'billiard'),
			  ), 
			  array(
			    'id'      => 'shop_heading_subtitle',
			    'type'    => 'text',
			    'title'   => esc_html__('Shop heading subtitle', 'billiard'),
			  ), 
			  array(
			    'id'      => 'products_per_row',
			    'type'    => 'select',
			    'title'   => esc_html__('Products per row', 'billiard'),
			    'options' => array(
			      'col-sm-6 col-md-4'  => esc_html__('Three columns', 'billiard'),
			      'col-sm-6 col-md-3'  => esc_html__('Four columns', 'billiard'),
			      'col-md-6'  => esc_html__('Two columns', 'billiard'),
			    ),
			    'default' => esc_html__('col-md-4', 'billiard'),
			  ),
			),
		);
		return $options;
	}
}
add_filter( 'eccommerce_theme_options', 'billiard_woocommerce_theme_options' );

/* add banner to shop page */
if ( ! function_exists('billiard_add_shop_banner')) {
	function billiard_add_shop_banner( )
	{	
		$class_banner = cs_get_option('shop_heading_image') ? 'banner-text-white' : '';
		?>
		<?php if ( ( cs_get_option('shop_heading_title') || cs_get_option('shop_heading_description')) && ( is_shop() || is_product() || is_cart() )  ): ?>
		<div class="banner-shop s-back-switch <?php echo esc_attr( $class_banner ); ?>">
	    	<span class="enable_overlay"></span>
		    <div class="container">
		    	
			    <?php 
			    	if(cs_get_option('shop_heading_image')) {
			    		echo wp_get_attachment_image( cs_get_option('shop_heading_image'), 'full', '', array('class'=>'s-img-switch') ); 
			    	}
			    ?>

			    <?php if (cs_get_option('shop_heading_title')) { ?>
			    <h2 class="banner-shop__title"><?php echo esc_html(cs_get_option('shop_heading_title')); ?></h2>
			    <?php } ?>

			    <?php if (cs_get_option('shop_heading_description')): ?>
			    <div class="banner-shop__description">
			        <?php echo esc_html( cs_get_option('shop_heading_description') ); ?>
			    </div>
			    <?php endif ?>
		    </div>

		
		</div>
		<?php endif ?>
		<?php
	}
}
add_action( 'billiard_after_header', 'billiard_add_shop_banner' );


if ( ! function_exists('billiard_shop_post_class')) {
	function billiard_shop_post_class($classes)
	{

		if(is_shop()){
			$classes[] = cs_get_option('products_per_row').' col-sm-6 col-xs-12';
			if(($key = array_search('product', $classes)) !== false) {
			    unset($classes[$key]);
			}  
		}

		return $classes;
	}
}
add_filter( 'post_class', 'billiard_shop_post_class',100) ;


